@@ -159,13 +159,14 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 	}
 
 	tagname = (const char *) xmlTextReaderConstName (parser->xml);
-	if (!strcmp (tagname, "name") && !loc->english_name) {
+	if ((!strcmp (tagname, "name") || !strcmp (tagname, "_name")) && !loc->english_name) {
             loc->msgctxt = _gweather_parser_get_msgctxt_value (parser);
 	    value = _gweather_parser_get_value (parser);
 	    if (!value)
 		goto error_out;
 
-	    loc->english_name = value;
+	    loc->english_name = g_strdup (value);
+
 	    if (loc->msgctxt) {
 		loc->local_name = g_strdup (g_dpgettext2 ("libgweather-locations",
 							  (char*) loc->msgctxt, value));
@@ -180,6 +181,7 @@ location_new_from_xml (GWeatherParser *parser, GWeatherLocationLevel level,
 	    normalized = g_utf8_normalize (loc->english_name, -1, G_NORMALIZE_ALL);
 	    loc->english_sort_name = g_utf8_casefold (normalized, -1);
 	    g_free (normalized);
+	    xmlFree (value);
 	} else if (!strcmp (tagname, "iso-code") && !loc->country_code) {
 	    value = _gweather_parser_get_value (parser);
 	    if (!value)
@@ -401,6 +403,7 @@ gweather_location_unref (GWeatherLocation *loc)
     g_free (loc->tz_hint);
     g_free (loc->station_code);
     g_free (loc->forecast_zone);
+    g_free (loc->yahoo_id);
     g_free (loc->radar);
 
     if (loc->children) {
