@@ -47,34 +47,48 @@ typedef enum { /*< underscore_name=gweather_location_level >*/
     GWEATHER_LOCATION_DETACHED
 } GWeatherLocationLevel;
 
+GWEATHER_EXTERN
 GType gweather_location_get_type (void);
 #define GWEATHER_TYPE_LOCATION (gweather_location_get_type ())
 
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_get_world      (void);
 
-G_DEPRECATED_FOR(gweather_location_get_world)
+GWEATHER_EXTERN G_DEPRECATED_FOR(gweather_location_get_world)
 GWeatherLocation      *gweather_location_new_world      (gboolean use_regions);
 
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_ref            (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 void                   gweather_location_unref          (GWeatherLocation  *loc);
 
+GWEATHER_EXTERN
 const char            *gweather_location_get_name       (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 const char            *gweather_location_get_sort_name  (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 GWeatherLocationLevel  gweather_location_get_level      (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_get_parent     (GWeatherLocation  *loc);
 
+GWEATHER_EXTERN
 GWeatherLocation     **gweather_location_get_children   (GWeatherLocation  *loc);
 
+GWEATHER_EXTERN
 gboolean               gweather_location_has_coords     (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 void                   gweather_location_get_coords     (GWeatherLocation  *loc,
 							 double            *latitude,
 							 double            *longitude);
+GWEATHER_EXTERN
 double                 gweather_location_get_distance   (GWeatherLocation  *loc,
 							 GWeatherLocation  *loc2);
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_find_nearest_city (GWeatherLocation *loc,
 							    double            lat,
 							    double            lon);
 
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_find_nearest_city_full (GWeatherLocation  *loc,
 								 double             lat,
 								 double             lon,
@@ -82,37 +96,52 @@ GWeatherLocation      *gweather_location_find_nearest_city_full (GWeatherLocatio
 								 gpointer           user_data,
 								 GDestroyNotify     destroy);
 
+GWEATHER_EXTERN
 void                  gweather_location_detect_nearest_city (GWeatherLocation   *loc,
 							     double              lat,
 							     double              lon,
 							     GCancellable       *cancellable,
 							     GAsyncReadyCallback callback,
 							     gpointer            user_data);
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_detect_nearest_city_finish (GAsyncResult *result, GError **error);
 
+GWEATHER_EXTERN
 const char            *gweather_location_get_country    (GWeatherLocation  *loc);
 
+GWEATHER_EXTERN
 GWeatherTimezone      *gweather_location_get_timezone   (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 GWeatherTimezone     **gweather_location_get_timezones  (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 void                   gweather_location_free_timezones (GWeatherLocation  *loc,
 							 GWeatherTimezone **zones);
 
+GWEATHER_EXTERN
 const char            *gweather_location_get_code       (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 char                  *gweather_location_get_city_name  (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 char                  *gweather_location_get_country_name (GWeatherLocation  *loc);
 
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_find_by_station_code (GWeatherLocation *world,
 							       const gchar      *station_code);
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_find_by_country_code (GWeatherLocation *world,
 							       const gchar      *country_code);
 
+GWEATHER_EXTERN
 gboolean               gweather_location_equal          (GWeatherLocation  *one,
 							 GWeatherLocation  *two);
 
+GWEATHER_EXTERN
 GVariant              *gweather_location_serialize      (GWeatherLocation  *loc);
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_deserialize    (GWeatherLocation  *world,
 							 GVariant          *serialized);
 
+GWEATHER_EXTERN
 GWeatherLocation      *gweather_location_new_detached   (const char        *name,
 							 const char        *icao,
 							 gdouble            latitude,
