@@ -75,53 +75,88 @@ struct _GWeatherInfoClass {
     void (*updated) (GWeatherInfo *info);
 };
 
+GWEATHER_EXTERN
 GType                    gweather_info_get_type            (void) G_GNUC_CONST;
+GWEATHER_EXTERN
 GWeatherInfo *           gweather_info_new                 (GWeatherLocation     *location,
 							    GWeatherForecastType  type);
+GWEATHER_EXTERN
 void                     gweather_info_update              (GWeatherInfo *info);
+GWEATHER_EXTERN
 void			 gweather_info_abort		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 void                     gweather_info_store_cache         (void);
 
+GWEATHER_EXTERN
 GWeatherProvider         gweather_info_get_enabled_providers (GWeatherInfo        *info);
+GWEATHER_EXTERN
 void                     gweather_info_set_enabled_providers (GWeatherInfo        *info,
 							      GWeatherProvider     providers);
 
+GWEATHER_EXTERN
 gboolean		 gweather_info_is_valid		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gboolean		 gweather_info_network_error	   (GWeatherInfo *info);
 
+GWEATHER_EXTERN
 const GWeatherLocation * gweather_info_get_location	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 void                     gweather_info_set_location        (GWeatherInfo *info,
 							    GWeatherLocation *location);
+GWEATHER_EXTERN
 gchar *		         gweather_info_get_location_name   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_update	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_sky		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar *	                 gweather_info_get_conditions	   (GWeatherInfo *info);
 
-G_DEPRECATED_FOR(gweather_info_get_forecast_list)
+GWEATHER_EXTERN G_DEPRECATED_FOR(gweather_info_get_forecast_list)
 gchar *                  gweather_info_get_forecast        (GWeatherInfo *info);
 
+GWEATHER_EXTERN
 gchar * 	  	 gweather_info_get_temp		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 	 	 gweather_info_get_temp_min	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_temp_max	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_dew		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_humidity	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_wind		   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_pressure	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_visibility	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_apparent	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_sunrise	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_sunset	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 GSList *		 gweather_info_get_forecast_list   (GWeatherInfo *info);
+GWEATHER_EXTERN
 GdkPixbufAnimation *	 gweather_info_get_radar	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 const gchar             *gweather_info_get_attribution     (GWeatherInfo *info);
 
+GWEATHER_EXTERN
 gchar * 		 gweather_info_get_temp_summary	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gchar *			 gweather_info_get_weather_summary (GWeatherInfo *info);
 
+GWEATHER_EXTERN
 const gchar *		 gweather_info_get_icon_name	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 const gchar *		 gweather_info_get_symbolic_icon_name	   (GWeatherInfo *info);
+GWEATHER_EXTERN
 gint			 gweather_info_next_sun_event	   (GWeatherInfo *info);
 
+GWEATHER_EXTERN
 gboolean                 gweather_info_is_daytime          (GWeatherInfo *info);
 
 /* values retrieving functions */
@@ -174,7 +209,11 @@ typedef enum { /*< underscore_name=gweather_wind_direction >*/
     GWEATHER_WIND_LAST
 } GWeatherWindDirection;
 
+GWEATHER_EXTERN
 const gchar * gweather_wind_direction_to_string (GWeatherWindDirection wind);
+GWEATHER_EXTERN
+const gchar * gweather_wind_direction_to_string_full (GWeatherWindDirection wind,
+                                                      GWeatherFormatOptions options);
 
 /**
  * GWeatherSky:
@@ -201,7 +240,11 @@ typedef enum { /*< underscore_name=gweather_sky >*/
     GWEATHER_SKY_LAST
 } GWeatherSky;
 
+GWEATHER_EXTERN
 const gchar * gweather_sky_to_string (GWeatherSky sky);
+GWEATHER_EXTERN
+const gchar * gweather_sky_to_string_full (GWeatherSky        sky,
+                                           GWeatherFormatOptions options);
 
 /**
  * GWeatherConditionPhenomenon:
@@ -315,20 +358,35 @@ typedef gdouble GWeatherMoonPhase;
  */
 typedef gdouble GWeatherMoonLatitude;
 
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_update		(GWeatherInfo *info, time_t *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_sky		(GWeatherInfo *info, GWeatherSky *sky);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_conditions	(GWeatherInfo *info, GWeatherConditionPhenomenon *phenomenon, GWeatherConditionQualifier *qualifier);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_temp		(GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_temp_min	(GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_temp_max	(GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_dew		(GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_apparent	(GWeatherInfo *info, GWeatherTemperatureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_wind		(GWeatherInfo *info, GWeatherSpeedUnit unit, gdouble *speed, GWeatherWindDirection *direction);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_pressure	(GWeatherInfo *info, GWeatherPressureUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_visibility	(GWeatherInfo *info, GWeatherDistanceUnit unit, gdouble *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_sunrise	(GWeatherInfo *info, time_t *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_sunset 	(GWeatherInfo *info, time_t *value);
+GWEATHER_EXTERN
 gboolean gweather_info_get_value_moonphase      (GWeatherInfo *info, GWeatherMoonPhase *value, GWeatherMoonLatitude *lat);
+GWEATHER_EXTERN
 gboolean gweather_info_get_upcoming_moonphases  (GWeatherInfo *info, time_t *phases);
 
 typedef struct _GWeatherConditions GWeatherConditions;
@@ -355,8 +413,13 @@ struct _GWeatherConditions {
     GWeatherConditionQualifier qualifier;
 };
 
+GWEATHER_EXTERN
 const gchar * gweather_conditions_to_string (GWeatherConditions *conditions);
+GWEATHER_EXTERN
+const gchar * gweather_conditions_to_string_full (GWeatherConditions *conditions,
+                                                  GWeatherFormatOptions options);
 
+GWEATHER_EXTERN
 GWeatherTemperatureUnit gweather_temperature_unit_to_real (GWeatherTemperatureUnit unit);
 
 G_END_DECLS
