@@ -3,11 +3,14 @@
  * Simple program to reproduce METAR parsing results from command line
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
 #include <string.h>
 #include <stdio.h>
-#define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#include "weather-priv.h"
+#include "gweather-private.h"
 
 #ifndef BUFLEN
 #define BUFLEN 4096
